@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::DOHERTY;
 use strict;
 use warnings;
 # ABSTRACT: configure Dist::Zilla like DOHERTY
-our $VERSION = '0.39'; # VERSION
+our $VERSION = '0.40'; # VERSION
 
 
 use feature qw(say);
@@ -280,7 +280,7 @@ sub configure {
         'ExecDir',
         ( $self->custom_build
             ? 'ModuleBuild::Custom'
-            : (qw/ MakeMaker ModuleBuild DualBuilders /)
+            : 'MakeMaker'
         ),
     );
 
@@ -381,7 +381,7 @@ Dist::Zilla::PluginBundle::Author::DOHERTY - configure Dist::Zilla like DOHERTY
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
